TypedEventBus class

Constructors

TypedEventBus()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() Future<void>
emit<T extends Object>(T data) → void
Emit new event with data
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onEvent<T extends Object>(void onEvent(T data)) EventBusSubscription<Object>
Catch event with data type is T
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited