EventBusSubscription<T extends Object> class
Constructors
-
EventBusSubscription(void _onEvent(T data), StreamSubscription _subscription, EventBusSubscription<
Object> ? _parent)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onEvent<
V extends Object> (void onEvent(V data)) → EventBusSubscription< Object> -
Catch event with data type is
T -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited